==> woningwaardering-1.0.1-py3-none-any.whl: woningwaardering/vera/referentiedata/onderhoudsoort.py <==
from enum import Enum
from woningwaardering.vera.bvg.generated import Referentiedata


class Onderhoudsoort(Enum):
    inspectie = Referentiedata(
        code="INS",
        naam="Inspectie",
    )
    """
    Opdracht tot het uitvoeren van inspectie-/inventarisatie-werkzaamheden om vast te
    stellen óf en zo ja welke onderhoudswerkzaamheden moeten worden uitgevoerd. Dit
    kan een inspectie zijn naar aanleiding van een onduidelijk reparatieverzoek of
    naar aanleiding van een verhuurmutatie.
    """

    mutatie = Referentiedata(
        code="MUT",
        naam="Mutatie",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    verhuurmutatie.
    """

    planmatig = Referentiedata(
        code="PLN",
        naam="Planmatig",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    goedgekeurd MJO-budget
    """

    projectmatig = Referentiedata(
        code="PRJ",
        naam="Projectmatig",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    investeringsproject zoals verduurzaming, renovatie, etc.
    """

    reparatie = Referentiedata(
        code="REP",
        naam="Reparatie",
    )
    """
    Opdracht tot het uitvoeren van reparatiewerkzaamheden naar aanleiding van een
    geconstateerd defect
    """

    wmo_aanpassing = Referentiedata(
        code="WMO",
        naam="WMO Aanpassing",
    )
    """
    Bij benodigde aanpassing van de woning bij de zittende huurder (door ouderdom,
    invaliditeit aanbrengen van WMO-aanpassing)
    """

    woningverbetering = Referentiedata(
        code="WOV",
        naam="Woningverbetering",
    )
    """
    Bij aanpassing op verzoek van de huurder voor verbetering van het woongenot.
    Voorbeeld is het voortijdig vervangen van de wc-pot door een luxe uiitvoering
    """

    @property
    def code(self) -> str:
        if self.value.code is None:
            raise TypeError("de code van een Referentiedata object mag niet None zijn")
        return self.value.code

    @property
    def naam(self) -> str | None:
        return self.value.naam

    @property
    def parent(self) -> Referentiedata | None:
        return self.value.parent

==> woningwaardering-3.0.1-py3-none-any.whl: woningwaardering/vera/referentiedata/onderhoudsoort.py <==
from woningwaardering.vera.bvg.generated import Referentiedata
from woningwaardering.vera.referentiedatasoort import Referentiedatasoort


class OnderhoudsoortReferentiedata(Referentiedata):
    pass


class Onderhoudsoort(Referentiedatasoort):
    inspectie = OnderhoudsoortReferentiedata(
        code="INS",
        naam="Inspectie",
    )
    """
    Opdracht tot het uitvoeren van inspectie-/inventarisatie-werkzaamheden om vast te
    stellen óf en zo ja welke onderhoudswerkzaamheden moeten worden uitgevoerd. Dit
    kan een inspectie zijn naar aanleiding van een onduidelijk reparatieverzoek of
    naar aanleiding van een verhuurmutatie.
    """

    mutatie = OnderhoudsoortReferentiedata(
        code="MUT",
        naam="Mutatie",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    verhuurmutatie.
    """

    planmatig = OnderhoudsoortReferentiedata(
        code="PLN",
        naam="Planmatig",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    goedgekeurd MJO-budget
    """

    projectmatig = OnderhoudsoortReferentiedata(
        code="PRJ",
        naam="Projectmatig",
    )
    """
    Opdracht tot het uitvoeren van onderhoudswerkzaamheden naar aanleiding van een
    investeringsproject zoals verduurzaming, renovatie, etc.
    """

    reparatie = OnderhoudsoortReferentiedata(
        code="REP",
        naam="Reparatie",
    )
    """
    Opdracht tot het uitvoeren van reparatiewerkzaamheden naar aanleiding van een
    geconstateerd defect
    """

    wmo_aanpassing = OnderhoudsoortReferentiedata(
        code="WMO",
        naam="WMO Aanpassing",
    )
    """
    Bij benodigde aanpassing van de woning bij de zittende huurder (door ouderdom,
    invaliditeit aanbrengen van WMO-aanpassing)
    """

    woningverbetering = OnderhoudsoortReferentiedata(
        code="WOV",
        naam="Woningverbetering",
    )
    """
    Bij aanpassing op verzoek van de huurder voor verbetering van het woongenot.
    Voorbeeld is het voortijdig vervangen van de wc-pot door een luxe uiitvoering
    """
